@@ -1,4 +1,4 @@
-"""DBT integeration"""
+"""dbt integeration"""
 
 from __future__ import annotations
 
@@ -16,6 +16,7 @@ from dbt.contracts.graph.parsed import (
     ParsedModelNode,
     ParsedGenericTestNode,
     ParsedSeedNode,
+    ParsedSourceDefinition,
 )
 from dbt.contracts.results import RunResultOutput
 from dbt.node_types import NodeType
@@ -24,9 +25,10 @@ from dbt.node_types import NodeType
 def parse_manifest(
     manifest: dict[str, Any]
 ) -> tuple[
-    dict[str, ParsedModelNode | CompileModelNode],
+    dict[str, ParsedModelNode | CompiledModelNode],
     dict[str, ParsedSeedNode | CompiledSeedNode],
     dict[str, ParsedGenericTestNode | CompiledGenericTestNode],
+    dict[str, ParsedSourceDefinition],
 ]:
     """
     Parse the manifest.
@@ -44,6 +46,7 @@ def parse_manifest(
             dict[str, ParsedModelNode | CompileModelNode],
             dict[str, ParsedSeedNode | CompiledSeedNode],
             dict[str, ParsedGenericTestNode | CompiledGenericTestNode],
+            dict[str, ParsedSourceDefinition],
           ]
         The parsed manifest.
 
@@ -56,10 +59,6 @@ def parse_manifest(
     ------
     https://docs.getdbt.com/reference/artifacts/manifest-json
     """
-    dbt_v4_schema = "https://schemas.getdbt.com/dbt/manifest/v4.json"
-    if manifest["metadata"]["dbt_schema_version"] != dbt_v4_schema:
-        raise NotImplementedError("Dbt manifest parsing only supported for V4 schema.")
-
     model_nodes = {
         node_name: CompiledModelNode(**node)
         if "compiled" in node.keys()
@@ -79,7 +78,12 @@ def parse_manifest(
         for node_name, node in manifest["nodes"].items()
         if node["resource_type"] == NodeType.Test
     }
-    return model_nodes, seed_nodes, test_nodes
+    source_nodes = {
+        source_name: ParsedSourceDefinition(**source)
+        for source_name, source in manifest["sources"].items()
+        if source["resource_type"] == NodeType.Source
+    }
+    return model_nodes, seed_nodes, test_nodes, source_nodes
 
 
 def parse_run_results(run_results: dict[str, Any]) -> list[RunResultOutput]:
@@ -107,10 +111,6 @@ def parse_run_results(run_results: dict[str, Any]) -> list[RunResultOutput]:
     ------
     https://docs.getdbt.com/reference/artifacts/run-results-json
     """
-    dbt_v4_schema = "https://schemas.getdbt.com/dbt/run-results/v4.json"
-    if run_results["metadata"]["dbt_schema_version"] != dbt_v4_schema:
-        raise NotImplementedError("Dbt run results parsing only supported for v4 schema.")
-
     parsed_run_results = [RunResultOutput(**result) for result in run_results["results"]]
     return parsed_run_results
 
